@@ -1,12 +1,8 @@
-
 """
-File:
-    ex_dsl2gse.py
-
-Description:
     Load tha_fgl_dsl and perform a dsl to gse transformation.
 
-Notes:
+Notes
+-----
     To duplicate this example on IDL SPEDAS, run the following code:
 
     pro thm_crib_fgm4
@@ -35,8 +31,7 @@ from pyspedas.themis.cotrans.dsl2gse import dsl2gse
 
 
 def ex_dsl2gse():
-    """ Example of dsl2dse"""
-
+    """Run dsl2gse."""
     time_range = ['2017-03-23 00:00:00', '2017-03-23 23:59:59']
     pyspedas.themis.state(probe='a', trange=time_range, get_support_data=True,
                           varnames=['tha_spinras', 'tha_spindec'])
@@ -56,3 +51,7 @@ def ex_dsl2gse():
 
     # Return 1 as indication that the example finished without problems.
     return 1
+
+
+# Run the example code
+ex_dsl2gse()
