@@ -45,4 +45,4 @@ def ex_gmag():
     return 1
 
 # Run the example code
-# ex_gmag()
+ex_gmag()
