@@ -12,9 +12,9 @@ from pyspedas import tdpwrspc
 
 ############### DSP ############### 
 class DSPLoadTestCases(unittest.TestCase):
-    def test_load_default_data(self):
-        data = mms_load_dsp(trange=['2015-08-01','2015-09-01'], datatype='swd', level='l2', data_rate='fast')
-        self.assertTrue(data_exists('mms1_dsp_swd_E12_Counts'))
+    # def test_load_default_data(self):
+    #     data = mms_load_dsp(trange=['2015-08-01','2015-09-01'], datatype='swd', level='l2', data_rate='fast')
+    #     self.assertTrue(data_exists('mms1_dsp_swd_E12_Counts'))
 
     def test_load_epsd_bpsd_data(self):
         data = mms_load_dsp(trange=['2015-08-01','2015-08-02'], datatype=['epsd', 'bpsd'], level='l2', data_rate='fast')
@@ -286,26 +286,24 @@ class SCMLoadTestCases(unittest.TestCase):
         self.assertTrue(data_exists('mms4_scm_acb_gse_scb_brst_l2_1_dpwrspc'))
         self.assertTrue(data_exists('mms4_scm_acb_gse_scb_brst_l2_2_dpwrspc'))
 
-############### SCM ############### 
-# class SCMLoadTestCases(unittest.TestCase):
-#     def test_load_default_data(self):
-#         data = mms_load_scm(trange=['2015-10-16', '2015-10-16/01:00'])
-#         self.assertTrue(data_exists('mms1_scm_acb_gse_scsrvy_srvy_l2'))
+    def test_load_default_data(self):
+        data = mms_load_scm(trange=['2015-10-16', '2015-10-16/01:00'])
+        self.assertTrue(data_exists('mms1_scm_acb_gse_scsrvy_srvy_l2'))
 
-#     def test_load_suffix(self):
-#         data = mms_load_scm(trange=['2015-10-16', '2015-10-16/01:00'], suffix='_test')
-#         self.assertTrue(data_exists('mms1_scm_acb_gse_scsrvy_srvy_l2_test'))
+    def test_load_suffix(self):
+        data = mms_load_scm(trange=['2015-10-16', '2015-10-16/01:00'], suffix='_test')
+        self.assertTrue(data_exists('mms1_scm_acb_gse_scsrvy_srvy_l2_test'))
 
-#     def test_load_multiple_sc(self):
-#         data = mms_load_scm(probe=['1', '2', '3', '4'], trange=['2017-12-15', '2017-12-16'])
-#         # self.assertTrue(data_exists('mms1_scm_acb_gse_scsrvy_srvy_l2'))
-#         # self.assertTrue(data_exists('mms2_scm_acb_gse_scsrvy_srvy_l2'))
-#         self.assertTrue(data_exists('mms3_scm_acb_gse_scsrvy_srvy_l2'))
-#         self.assertTrue(data_exists('mms4_scm_acb_gse_scsrvy_srvy_l2'))
+    def test_load_multiple_sc(self):
+        data = mms_load_scm(probe=['1', '2', '3', '4'], trange=['2017-12-15', '2017-12-16'])
+        # self.assertTrue(data_exists('mms1_scm_acb_gse_scsrvy_srvy_l2'))
+        # self.assertTrue(data_exists('mms2_scm_acb_gse_scsrvy_srvy_l2'))
+        self.assertTrue(data_exists('mms3_scm_acb_gse_scsrvy_srvy_l2'))
+        self.assertTrue(data_exists('mms4_scm_acb_gse_scsrvy_srvy_l2'))
 
-#     def test_load_brst_data(self):
-#         data = mms_load_scm(data_rate='brst', trange=['2015-10-16/13:06', '2015-10-16/13:10'], datatype='scb')
-#         self.assertTrue(data_exists('mms1_scm_acb_gse_scb_brst_l2'))
+    def test_load_brst_data(self):
+        data = mms_load_scm(data_rate='brst', trange=['2015-10-16/13:06', '2015-10-16/13:10'], datatype='scb')
+        self.assertTrue(data_exists('mms1_scm_acb_gse_scb_brst_l2'))
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
